@@ -396,7 +396,7 @@ void TQLCDNumber::setNumDigits( int numDigits )
         bool doDisplay = ndigits == 0;
         if ( numDigits == ndigits )             // no change
             return;
-        register int i;
+        int i;
         int dif;
         if ( numDigits > ndigits ) {            // expand
             dif = numDigits - ndigits;
